Build a minimal wrapper script that only applies resource limits
Source:R/rlimits.R
build_limits_only_wrapper.RdUsed when sandbox = FALSE but limits is provided. Creates a shell
wrapper that sets ulimit values and then execs R.
R/rlimits.R
build_limits_only_wrapper.RdUsed when sandbox = FALSE but limits is provided. Creates a shell
wrapper that sets ulimit values and then execs R.