Generate the R code to inject into the child process
Source:R/child-runtime.R
child_runtime_code.RdReturns a character string of R code that, when evaluated in the child
process, sets up the IPC connection and defines .securer_call_tool().